# main file for semaphore

import os
import sys
import time
import json
import requests
from . import serve

def server():
    print("server")
    return 0

def setup():
    print("setup")
    return 0

def test():
    print("test")
    return 0

def version():
    print("0.0.2")
    return 0

def audit():
    print("audit")
    return 0

def init():
    print("init")
    return 0

def start():
    print("start")
    return 0

def stop():
    print("stop")
    return 0

def restart():
    print("restart")
    return 0

