import os
import sys
from ..common import prettyllog




def main():
    prettyllog("ui", "ui", "ui", "new", "000", "ui")
    kalm_ui_port  = os.environ.get("KALM_UI_PORT", "8000")
    kalm_ui_host = os.environ.get("KALM_UI_HOST", "kalm.openknowit.com")
    kalm_ui_debug = os.environ.get("KALM_UI_DEBUG", "True")
    kalm_


                          
